@@ -1,10 +1,7 @@
-# @(#)Ident: Types.pm 2014-01-24 20:20 pjf ;
-
 package Unexpected::Types;
 
 use strict;
 use warnings;
-use namespace::clean -except => 'meta';
 
 use English               qw( -no_match_vars );
 use Module::Runtime       qw( is_module_name require_module );
@@ -17,8 +14,12 @@ use Type::Utils           qw( as coerce extends from
                               inline_as message subtype via where );
 use Unexpected::Functions qw( inflate_message );
 
+use namespace::clean -except => 'meta';
+
 BEGIN { extends 'Types::Standard' };
 
+my $LOADABLE_CLASS_ERROR;
+
 $Error::TypeTiny::CarpInternal{ 'Sub::Quote' }++;
 $Error::TypeTiny::CarpInternal{ 'Unexpected::TraitFor::Throwing' }++;
 
@@ -58,7 +59,8 @@ subtype Tracer, as Object,
 
 
 subtype LoadableClass, as NonEmptySimpleStr,
-   message   { inflate_message( 'String [_1] is not a loadable class', $_ ) },
+   message   { inflate_message( 'String [_1] is not a loadable class: [_2]',
+                                $_, $LOADABLE_CLASS_ERROR ) },
    where     { __constraint_for_loadable_class( $_ ) };
 
 subtype NonNumericSimpleStr, as SimpleStr,
@@ -74,6 +76,8 @@ sub __constraint_for_loadable_class {
 
    local $EVAL_ERROR; eval { require_module( $class ) };
 
+   $LOADABLE_CLASS_ERROR = $EVAL_ERROR;
+
    return $EVAL_ERROR ? 0 : 1;
 }
 
